# analytics

## Dépendances
```shell
analytics
└─ core
└─ scheme
└─ accordion
└─ button
└─ breadcrumb
└─ sidemenu
└─ tab
└─ tooltip
└─ display
└─ table
└─ tag
└─ toggle
└─ modal
└─ navigation
└─ password
└─ header
```

## Utilisation
Afin d’utiliser le composant `analytics`, il est nécessaire d’ajouter les fichiers de styles et de scripts présents dans le dossier dist dans l'ordre suivant :\n
```html
<html>
  <head>
  </head>
  <body>
    <script type="text/javascript" nomodule href="js/legacy/legacy.nomodule.min.js" ></script>
    <script type="module" href="js/core/core.module.min.js" ></script>
    <script type="text/javascript" nomodule href="js/core/core.nomodule.min.js" ></script>
    <script type="module" href="js/scheme/scheme.module.min.js" ></script>
    <script type="module" href="js/accordion/accordion.module.min.js" ></script>
    <script type="text/javascript" nomodule href="js/accordion/accordion.nomodule.min.js" ></script>
    <script type="module" href="js/button/button.module.min.js" ></script>
    <script type="text/javascript" nomodule href="js/button/button.nomodule.min.js" ></script>
    <script type="module" href="js/navigation/navigation.module.min.js" ></script>
    <script type="text/javascript" nomodule href="js/navigation/navigation.nomodule.min.js" ></script>
    <script type="module" href="js/modal/modal.module.min.js" ></script>
    <script type="text/javascript" nomodule href="js/modal/modal.nomodule.min.js" ></script>
    <script type="module" href="js/breadcrumb/breadcrumb.module.min.js" ></script>
    <script type="text/javascript" nomodule href="js/breadcrumb/breadcrumb.nomodule.min.js" ></script>
    <script type="module" href="js/toggle/toggle.module.min.js" ></script>
    <script type="text/javascript" nomodule href="js/toggle/toggle.nomodule.min.js" ></script>
    <script type="module" href="js/sidemenu/sidemenu.module.min.js" ></script>
    <script type="text/javascript" nomodule href="js/sidemenu/sidemenu.nomodule.min.js" ></script>
    <script type="module" href="js/password/password.module.min.js" ></script>
    <script type="text/javascript" nomodule href="js/password/password.nomodule.min.js" ></script>
    <script type="module" href="js/tab/tab.module.min.js" ></script>
    <script type="text/javascript" nomodule href="js/tab/tab.nomodule.min.js" ></script>
    <script type="module" href="js/tooltip/tooltip.module.min.js" ></script>
    <script type="text/javascript" nomodule href="js/tooltip/tooltip.nomodule.min.js" ></script>
    <script type="module" href="js/table/table.module.min.js" ></script>
    <script type="text/javascript" nomodule href="js/table/table.nomodule.min.js" ></script>
    <script type="module" href="js/tag/tag.module.min.js" ></script>
    <script type="text/javascript" nomodule href="js/tag/tag.nomodule.min.js" ></script>
    <script type="module" href="js/header/header.module.min.js" ></script>
    <script type="text/javascript" nomodule href="js/header/header.nomodule.min.js" ></script>
    <script type="module" href="js/display/display.module.min.js" ></script>
    <script type="text/javascript" nomodule href="js/display/display.nomodule.min.js" ></script>
    <script type="module" href="js/analytics/analytics.module.min.js" ></script>
    <script type="text/javascript" nomodule href="js/analytics/analytics.nomodule.min.js" ></script>
  </body>
</html>
```